;; Debian adjustments for project.clj

(require '[debian.dh-clojure-lein.client :as deb])

(defn dh-clj-adjust-project [project when & _]
  "Drop eastwood plugin."
  (case when
    :before-plugins
    (-> (project)
        (assoc :local-repo "debian/dh-clojure/tmp/maven-repo")
        (update :plugins deb/del-dep 'jonase/eastwood))
    (project)))
